import json
import logging
import os

from flask import Flask, g
from flask_oidc import OpenIDConnect
import requests
from werkzeug.middleware.proxy_fix import ProxyFix

logging.basicConfig(level=logging.DEBUG)

app = Flask(__name__)
app.config.update({
    'SECRET_KEY': os.environ['SECRET'],
    'DEBUG': False,
    'OIDC_CLIENT_SECRETS': json.loads(os.environ['CLIENT_SECRETS']),
    'OIDC_ID_TOKEN_COOKIE_SECURE': False,
    'OIDC_USER_INFO_ENABLED': True,
    'OIDC_OPENID_REALM': 'hottis',
    'OIDC_SCOPES': ['openid', 'email', 'profile']
})

oidc = OpenIDConnect(app)


@app.route('/')
def hello_world():
    if oidc.user_loggedin:
        return ('Hello, %s, <a href="/private">See private</a> '
                '<a href="/logout">Log out</a>') % \
            oidc.user_getfield('preferred_username')
    else:
        return 'Welcome anonymous, <a href="/private">Log in</a>'


@app.route('/private')
@oidc.require_login
def hello_me():
    """Example for protected endpoint that extracts private information from the OpenID Connect id_token.
       Uses the accompanied access_token to access a backend service.
    """

    info = oidc.user_getinfo(['preferred_username', 'email', 'sub', 'roles'])

    username = info.get('preferred_username')
    email = info.get('email')
    user_id = info.get('sub')
    roles = info.get('roles')

    return ("""%s, %s, %s, %s!
               <ul>
                 <li><a href="/">Home</a></li>
                 <li><a href="/logout">Logout</a></li>
                </ul>""" %
            (username, email, user_id, roles))


# @app.route('/api', methods=['POST'])
# @oidc.accept_token(require_token=True, scopes_required=['openid'])
# def hello_api():
#     """OAuth 2.0 protected API endpoint accessible via AccessToken"""
# 
#     return json.dumps({'hello': 'Welcome %s' % g.oidc_token_info['sub']})


@app.route('/logout')
def logout():
    """Performs local logout by removing the session cookie."""

    oidc.logout()
    return 'Hi, you have been logged out! <a href="/">Return</a>'


app = ProxyFix(app, x_for=1, x_host=1)


